/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.extension.registry.overlay;


/**
 * <p>
 * This service provides an embedded Petals Registry Overlay.
 * </p>
 * <p>
 * This extension is used to simplify the usage of Petals ESB in case of a default standalone topology, avoiding to
 * start an external Petals Registry Overlay as another system process.
 * </p>
 * <p>
 * This extension is activated according to the following rules, in order:
 * </p>
 * <ol>
 * <li>the topology is a standalone topology (ie. with only one container),</li>
 * <li>no registry client implementation is set,</li>
 * <li>the activation property '{@link #ACTIVATION_PROPERTY_NAME}' ({@value #ACTIVATION_PROPERTY_NAME}) is not set, or
 * set to {@link #DEFAULT_ACTIVATION} ({@value #DEFAULT_ACTIVATION}).</li>
 * </ol>
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface EmbeddedRegistryOverlayService {

    /**
     * Prefix of the properties of the pre-extesion
     */
    public static final String PREFIX_PROPERTY_NAME = "petals.embedded-registry-overlay";

    /**
     * Name of the property enabling/disabling the pre-extension.
     */
    public static final String ACTIVATION_PROPERTY_NAME = PREFIX_PROPERTY_NAME;

    /**
     * Default value of the property {@value #ACTIVATION_PROPERTY_NAME}.
     */
    public static final boolean DEFAULT_ACTIVATION = true;

    /**
     * Name of the property defining the listening port of the embedded registry.
     */
    public static final String PORT_PROPERTY_NAME = PREFIX_PROPERTY_NAME + ".port";

    /**
     * Logger name of the extension
     */
    public static final String FRACTAL_COMPONENT_LOGGER_NAME = "Petals.Extensions.EmbeddedRegistryOverlayService";

}
